================================
Release Notes for older versions
================================

These are release notes for version up to 1.2.4. With 1.2.5, the
handling of release notes has changed.

1.2.4
-----

* Add links for Liberty.
* Fix the broken anchor tags.
* Remove unused files.
* Fix table padding.
  https://bugs.launchpad.net/bugs/1439918

1.2.3
-----

* Add padding to the left table of contents
* Decrease the indent of TOC entries on the 2nd level
* Fix broken links for firstapp and other repos.
  https://bugs.launchpad.net/bugs/1461185
* Remove executable flags from js/css files
* Set the width of the highlight table to 100%

1.2.2
-----

* Cleanup of HTML template files and CSS files
* Fix link to the OpenStack summit
* Fix links/texts in the license footer
* Link the Apache 2.0 license note in the footer
* Move listed guides in the sidebar into the dropdown menu
* On hover don't change the background color of the sidebar TOC
* Remove 'suggest edits' link from layout
* Remove duplicate ask.openstack.org link from the footer
* Remove last release details from header/footer
* Remove the 'Sign in' link in the top bar

1.2.1
-----

* Fix inclusion of metatags.
* Remove unused images and javascript files.
* Fix "Docs Home" link.

1.2.0
-----

* Add next/previous buttons and report a bug link also at bottom of
  the page.
* Add dynamic table of content to sidebar.
  https://bugs.launchpad.net/openstack-manuals/+bug/1422454
* Fixed Korean typo on sidebartoc.
  https://bugs.launchpad.net/openstack-manuals/+bug/1474452
* Add loweralpha list-style for enumerated lists.
  https://bugs.launchpad.net/openstack-manuals/+bug/1476084

1.1.0
-----

* Make indentation on glossary definitions.
* Adds original CSS/JS files to repository.
* Improve navigation links.

1.0.8
-----

* Enhancement to "Report a bug" link by adding URL to current page reported
  from.

1.0.7
-----

* Adds "Report a bug" link with pre-filled information for Launchpad:
  https://bugs.launchpad.net/openstack-manuals/+bug/1421799

1.0.6
-----

* Adds CSS styling for code using "native" pygments style.
* Bug fix for Table of Contents links:
  https://bugs.launchpad.net/openstack-manuals/+bug/1422454

1.0.5
-----

* Bug fix for license text, CC-by rather than CC-by-sa:
  https://bugs.launchpad.net/openstack-manuals/+bug/1436515
* Adds next and previous links on every page:
  https://bugs.launchpad.net/openstack-manuals/+bug/1423064
* Adds Google Custom Search Engine rather than generic search form.
  https://bugs.launchpad.net/openstack-manuals/+bug/1431024

1.0.4
-----

* Bug fix for admonitions styling:
  https://bugs.launchpad.net/openstack-manuals/+bug/1416572
* Bug fix for a plus sign appearing when numbered list followed by bulleted
  list:
  https://bugs.launchpad.net/openstack-manuals/+bug/1417291

1.0.3
-----

Release was built from incorrect branch; revise again to fix line numbers.

1.0.2
-----

* Bug fix for added line number for code samples by removing function from
  docs.js and using Sphinx ``:linenos:`` markup instead:
  https://bugs.launchpad.net/openstack-manuals/+bug/1416570

1.0.1
-----

* Updated to ensure the app configuration works with global OpenStack

1.0.0
-----

* Initial release
